==> dm_0.2.8.tar.gz: dm/R/global.R <==
utils::globalVariables(c(
  # pipe
  ".",
  #
  # nesting
  "data",
  #
  # nycflights13
  "airlines",
  "airports",
  "carrier",
  "distance",
  "faa",
  "flights",
  "planes",
  "tailnum",
  "weather",
  "time_hour",
  #
  # dm
  "any_na",
  "arrange_col",
  "candidate",
  "cardinality",
  "child_fk_cols",
  "child_table",
  "colname",
  "color",
  "cols",
  "column",
  "columns",
  "constraint",
  "ct_name",
  "day",
  "dest",
  "df",
  "display",
  "filter_expr",
  "filters",
  "fks",
  "full_type",
  "indexes",
  "into",
  "is_key",
  "key",
  "key_fk",
  "col_tracker_zoom",
  "kind",
  "mismatch_or_null",
  "name",
  "need_ref",
  "new_display",
  "new_name",
  "node",
  "old",
  "origin",
  "parent",
  "parent_key_cols",
  "parent_table",
  "pk",
  "pk_col",
  "pks",
  "problem",
  "pt_name",
  "ref",
  "ref_col",
  "ref_column",
  "ref_table",
  "remote_name",
  "remote_name_unquoted",
  "renames",
  "schema",
  "schema_name",
  "source_name",
  "sub_text",
  "t1",
  "t1_name",
  "t2",
  "t2_name",
  "table_name",
  "tbl_name",
  "tbls",
  "text",
  "type",
  "unique_indexes",
  "value",
  "values",
  "why",
  "zoom",
  "zoomed",
  "extra",
  "on_delete",
  #
  # financial
  "account_id",
  "accounts",
  "cards",
  "client_id",
  "clients",
  "disp_id",
  "disps",
  "district_id",
  "districts",
  "loans",
  "orders",
  "trans",
  #
  # pixarfilms
  "pixar_films",
  "pixar_people",
  "academy",
  "box_office",
  "genres",
  "public_response",
  "film",
  "role_type",
  "award_type",
  "genre",
  #
  # build_copy_queries
  "col_def",
  "fk_def",
  "index_name",
  "remote_table",
  "remote_table_unquoted",
  "unique_def",
  #
  # keep this to avoid dealing with trailing commas
  NULL
))

==> dm_0.3.0.tar.gz: dm/R/global.R <==
utils::globalVariables(c(
  # pipe
  ".",
  #
  # nesting
  "data",
  #
  # nycflights13
  "airlines",
  "airports",
  "carrier",
  "distance",
  "faa",
  "flights",
  "planes",
  "tailnum",
  "weather",
  "time_hour",
  #
  # dm
  "any_na",
  "arrange_col",
  "candidate",
  "cardinality",
  "child_cols",
  "child_fk_cols",
  "child_table",
  "colname",
  "color",
  "cols",
  "column",
  "columns",
  "constraint",
  "ct_name",
  "day",
  "dest",
  "df",
  "display",
  "filter_expr",
  "filters",
  "fks",
  "full_type",
  "indexes",
  "into",
  "is_key",
  "key",
  "key_fk",
  "col_tracker_zoom",
  "kind",
  "mismatch_or_null",
  "n_c",
  "n_p",
  "name",
  "need_ref",
  "new_child_table",
  "new_fks",
  "new_parent_table",
  "new_display",
  "new_name",
  "new_table",
  "node",
  "old",
  "origin",
  "parent",
  "parent_cols",
  "parent_key_cols",
  "parent_table",
  "pk",
  "pk_col",
  "pks",
  "problem",
  "pt_name",
  "ref",
  "ref_col",
  "ref_column",
  "ref_table",
  "remote_name",
  "remote_name_unquoted",
  "renames",
  "schema",
  "schema_name",
  "source_name",
  "sub_text",
  "t1",
  "t1_name",
  "t2",
  "t2_name",
  "table_name",
  "tbl_name",
  "tbls",
  "text",
  "type",
  "unique_indexes",
  "value",
  "values",
  "why",
  "zoom",
  "zoomed",
  "extra",
  "on_delete",
  #
  # financial
  "account_id",
  "accounts",
  "cards",
  "client_id",
  "clients",
  "disp_id",
  "disps",
  "district_id",
  "districts",
  "loans",
  "orders",
  "trans",
  #
  # information_schema
  "catalog",
  "catalog_name",
  "column_default",
  "column_id",
  "column_name",
  "con",
  "constraint_catalog",
  "constraint_column_id",
  "constraint_column_usage",
  "constraint_name",
  "constraint_schema",
  "constraint_type",
  "dbname",
  "FIXME",
  "is_nullable",
  "key_column_usage",
  "object_id",
  "ordinal_position",
  "schema_id",
  "schemata",
  "table_catalog",
  "table_constraints",
  "table_schema",
  "table_type",
  "tables",
  "constraint_column_usage.column_name",
  "constraint_column_usage.dm_name",
  "key_column_usage.column_name",
  "key_column_usage.dm_name",
  #
  # pixarfilms
  "pixar_films",
  "pixar_people",
  "academy",
  "box_office",
  "genres",
  "public_response",
  "film",
  "role_type",
  "award_type",
  "genre",
  #
  # build_copy_queries
  "col_def",
  "fk_def",
  "index_name",
  "remote_table",
  "remote_table_unquoted",
  "unique_def",
  #
  # meta
  "DATABASE",
  "referenced_column_name",
  "referenced_table_name",
  "referenced_table_schema",
  #
  # keep this to avoid dealing with trailing commas
  NULL
))
